//
//  SwiftUIView.swift
//  UIKitComponents
//
//  Created by User on 26.05.2025.
//

import SwiftUI

public struct SelectView: View {
    
    @State var title: String
    @Binding var text: String
    let variants: [String]
    let titleOne: String
    
    public init(titleOne: String = "",title: String, text: Binding<String>, variants: [String]) {
        self.title = title
        self._text = text
        self.variants = variants
        self.titleOne = titleOne
    }
    
    public var body: some View {
        VStack(alignment: .leading, spacing: 0) {
            if !titleOne.isEmpty {
                Text(titleOne)
                    .robotoFlex(size: 14)
                    .foregroundStyle(Color("hex#7E7E9A", bundle: .module))
                    .tracking(0)
                    .lineSpacing(20)
                    .padding(.bottom, 4)
            }
            ZStack {
                Menu(content: {
                    ForEach(variants, id: \.self) { variant in
                        Button(variant) {
                            title = variant
                            text = variant
                        }
                    }
                    
                }, label: {
                    Text("")
                        .frame(maxWidth: .infinity)
                        .frame(height: 48)
                        .cornerRadius(10)
                        .background(
                            RoundedRectangle(cornerRadius: 10)
                                .foregroundStyle(Color("hex#F5F5F9", bundle: .module))
                                .overlay(content: {
                                    RoundedRectangle(cornerRadius: 10)
                                        .stroke(lineWidth: 1)
                                        .foregroundStyle(Color("hex#EBEBEB", bundle: .module))
                                })
                        )
                })
                HStack {
                    Text(title)
                        .robotoFlex(size: 16)
                        .foregroundStyle(variants.contains(title) ? Color.black : (Color("hex#939396", bundle: .module)))
                        .tracking(0.32)
                        .lineSpacing(20)
                    Spacer()
                    Image("down", bundle: .module)
                }.padding(.horizontal, 14)
            }
        }
    }
}

#Preview {
    SelectView(title: "Пол", text: .constant(""), variants: ["Male", "Female", "gay"])
}
